<?php
/**
 * @file HTTP POST server example - example of AGMO HTTP POST server usage
 * @author Jiri Bazant <jiri.bazant@comgate.cz>
 * @copyright Copyright (c) 2011, AGMO s.r.o.
 *
 * Example of using AGMO HTTP POST server
 * for more information about methods and parameters see protokol specification
 *
 * If you create instance Agmo_Http_Post_Server, it expects 2 callback functions
 *
 */

//include Agmo HTTP POST library
require_once('agmo_http_lib.php');

/**
 * Sample implementation of server for PUSH method, http post version.
 */

/**
 * Method is called when sms arrives
 *
 * You can specify array of SMS responses or return empty array.
 * If this method throws some exception, error response will be generated.
 *  - if Agmo_Http_Post_Exception is thrown error response with code "400 Bad Request" is generated
 *  - if Exception is thrown error response with code "500 Internal Error" is generated
 *
 * @param array $params Array of incoming MO SMS parameters
 * @return array
 */
function http_post_receiveSmsMO($params)
{
    //TODO here you can add your logic
    // params array can contain these indexes
    // 'methodName', 'messageId', 'appNumber', 'mobileNumber', 'messageText',
    // 'smscTime','billCode', 'operatorId', 'serviceId',
    // 'refNo', 'maxNo', 'refId', 'prefix1', 'prefix2'





    // you can optional specify
    // SMS directly in response
    // possible parameters are
    // 'methodName', 'messageText', 'dataType', 'billCode',
    // 'clientMessageId', 'refNo', 'maxNo', 'refId'
    $responses = array(
        array(
            'methodName' => 'sendSmsMT',
            'messageText' => 're1: ' . $params['messageText'],
            'dataType' => '0',
            'clientMessageId' => time() . (rand() % 100)
        ),

        array(
            'methodName' => 'sendSmsMT',
            'messageText' => 're2: ' . $params['messageText'],
            'dataType' => '0',
            'clientMessageId' => time() . (rand() % 100)
        ),
        //here you can add next responses
    );

    return $responses;
}

/**
 * Method is called when delivery report arrives
 * If this method throws some exception, error response will be generated.
 *  - if Agmo_Http_Post_Exception is thrown error response with code "400 Bad Request" is generated
 *  - if Exception is thrown error response with code "500 Internal Error" is generated
 *
 * @param array $params Array of incoming DLR parameters
 * @return null
 */
function http_post_receiveDlr($params)
{
    //TODO here you can add your logic
    // params array can contain these indexes
    // 'msgRefId', 'mobileNumber', 'appNumber', 'msgTime', 'msgTextPart', 'dlrTime', 'status'
    // 'methodName', 'clientMessageId', 'mobileNumber', 'appNumber', 'msgTime',
    // 'msgTextPart', 'dlrTime', 'status', 'statusDesc'
}

/*
 * Main program
 *
 */
// create Agmo_Http_Post_Server object
$server = new Agmo_Http_Post_Server(
    'appID',                    // ID of your application, provided by AGMO
    'my password',              // password
    'http_post_receiveSmsMO',   // callback for receiving MO SMS (see above)
    'http_post_receiveDlr'      // callback for receiving DLR (see above)
);

// dispatch request
$server->dispatch();
