<?php
/**
 * @file HTTP POST client example - send sms via web form
 * @author Jiri Bazant <jiri.bazant@comgate.cz>
 * @copyright Copyright (c) 2011, AGMO s.r.o.
 *
 * Simple web example
 * Shows, how to send MT SMS using html form
 * For base logic of sending sms see section -- example logic --
 *
 * For advanced usage see file client-advanced.php
 */

//include Agmo HTTP POST library
require_once('agmo_http_lib.php');

//------------ functions ---------------
/**
 *
 * @brief Populates form with values
 *
 * Populates form with values from POST, or with default values
 */
function fill_values()
{
    if (count($_POST) > 0) {
        //fill form with posted values
        $vals['mobile'] = $_POST['mobile'];
        $vals['msg'] = $_POST['message'];
        $vals['billcode'] = $_POST['billcode'];
        $vals['reply'] = $_POST['reply'];
    } else {
        //fill form with default values
        $vals['mobile'] = '+420';
        $vals['msg'] = 'Lorem ipsum Dolor sit amet.';
        $vals['billcode'] = NULL;
        $vals['reply'] = '0';
    }

    return $vals;
}


//------------ example logic ---------------
if (count($_POST) > 0) {
    try {
        //create http post client object
        $client = new Agmo_Http_Post_Client(
            'http://smsapi-test.agmo.eu/server/httppost/v5',// url, provided by agmo
            '304000', // login, provided by agmo
            'your_pass' // password, provided by agmo, can be changed via web client
        );

        //send SMS
        $res = $client->sendSmsMT(array(
            'messageText' => $_POST['message'],
            'billCode' => $_POST['billcode'],
            'mobileNumber' => $_POST['mobile'],
            'replyToId' => (int)$_POST['reply'],
        ));

    } catch (Agmo_Http_Post_Exception $e) {
        //display error when any error occurred
        $res = $e->getMessage();
    }
}

//populate html form
$values = fill_values();

//------------ html ---------------
// render HTML page with simple form
?>
<html>
    <head>
        <meta http-equiv="content-type" content="text/html; charset=utf-8" />
        <title>AGMO - example client</title>
    </head>
    <body>
        <?php
            //Display action result
            if (isset($res)) {
                echo '<p>Action result:</p><pre>';
                print_r($res);
                echo '</pre>';
            }
        ?>
        <form action="" method="POST" >
            <p><label for="mobile">Mobile number:</label></p>
            <p><input type="text" name="mobile" value="<?php echo $values['mobile']; ?>" /></p>
            <p><label for="message">Text:</label></p>
            <p><textarea rows="5" cols="20" name="message"><?php echo $values['msg']; ?></textarea></p>
            <p><label for="billcode">Bill code:</label></p>
            <p><input type="text" name="billcode" value="<?php echo $values['billcode']; ?>" /></p>
            <p><label for="reply">Reply to:</label></p>
            <p><input type="text" name="reply" value="<?php echo $values['reply']; ?>" /></p>
            <p><input type="submit" value="Odeslat"></p>
        </form>
    </body>
</html>
